# Connector

A connector describes the relative motions between two points. A connector also describes the behavior associated with the relative motion.

## Create connectors

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorSection.ConnectorSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### CDCTerm

```{eval-rst}
.. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CDCTermArray

```{eval-rst}
.. autoclass:: abaqus.Connector.CDCTermArray.CDCTermArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorBehaviorOption

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorBehaviorOption.ConnectorBehaviorOption
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorBehaviorOptionArray

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorDamage

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorDamping

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorElasticity

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorFailure

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorFriction

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorLock

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorOptions

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorOptions.ConnectorOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorPlasticity

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorPotential

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorPotentialArray

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorStop

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DerivedComponent

```{eval-rst}
.. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TangentialBehavior

```{eval-rst}
.. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Classes

### CDCTerm

```{eval-rst}
.. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
    :noindex:

    .. autoclasstoc::
```

### CDCTermArray

```{eval-rst}
.. autoclass:: abaqus.Connector.CDCTermArray.CDCTermArray
    :noindex:

    .. autoclasstoc::
```

### ConnectorBehaviorOption

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorBehaviorOption.ConnectorBehaviorOption
    :noindex:

    .. autoclasstoc::
```

### ConnectorBehaviorOptionArray

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray
    :noindex:

    .. autoclasstoc::
```

### ConnectorDamage

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
    :noindex:

    .. autoclasstoc::
```

### ConnectorDamping

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
    :noindex:

    .. autoclasstoc::
```

### ConnectorElasticity

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
    :noindex:

    .. autoclasstoc::
```

### ConnectorFailure

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
    :noindex:

    .. autoclasstoc::
```

### ConnectorFriction

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
    :noindex:

    .. autoclasstoc::
```

### ConnectorLock

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
    :noindex:

    .. autoclasstoc::
```

### ConnectorOptions

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorOptions.ConnectorOptions
    :noindex:

    .. autoclasstoc::
```

### ConnectorPlasticity

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
    :noindex:

    .. autoclasstoc::
```

### ConnectorPotential

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
    :noindex:

    .. autoclasstoc::
```

### ConnectorPotentialArray

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray
    :noindex:

    .. autoclasstoc::
```

### ConnectorStop

```{eval-rst}
.. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
    :noindex:

    .. autoclasstoc::
```

### DerivedComponent

```{eval-rst}
.. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
    :noindex:

    .. autoclasstoc::
```

### TangentialBehavior

```{eval-rst}
.. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
    :noindex:

    .. autoclasstoc::
```

% This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
